==> openwebmail-2.10.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/pt_BR/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Cabealho 1": "h1",
		"Cabealho 2": "h2",
		"Cabealho 3": "h3",
		"Cabealho 4": "h4",
		"Cabealho 5": "h5",
		"Cabealho 6": "h6",
		"Normal": "p",
		"Endereo": "address",
		"Pr-formatado": "pre"
	},

	tooltips: {
		bold:           "Negrito",
		italic:         "Itlico",
		underline:      "Sublinhado",
		strikethrough:  "Tachado",
		subscript:      "Subscrito",
		superscript:    "Sobrescrito",
		justifyleft:    "Alinhar  esquerda",
		justifycenter:  "Centralizado",
		justifyright:   "Alinhar  direita",
		justifyfull:    "Justificado",
		orderedlist:    "Lista ordenada",
		unorderedlist:  "Lista com marcadores",
		outdent:        "Diminuir Indentao",
		indent:         "Aumentar Indentao",
		forecolor:      "Cor da Fonte",
		backcolor:      "Cor do Fundo",
		horizontalrule: "Rgua Horizontal",
		createlink:     "Inserir link",
		insertimage:    "Inserir Imagem",
		insertsound:    "Inserir Som",
		inserttable:    "Inserir Tabela",
		htmlmode:       "Ver fonte HTML",
		popupeditor:    "Ampliar Editor",
		about:          "Sobre...",
		help:           "Ajuda",
		textindicator:  "Estilo Atual"
	}
};

==> openwebmail-2.51p2.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/pt_BR/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Cabealho 1": "h1",
		"Cabealho 2": "h2",
		"Cabealho 3": "h3",
		"Cabealho 4": "h4",
		"Cabealho 5": "h5",
		"Cabealho 6": "h6",
		"Normal": "p",
		"Endereo": "address",
		"Pr-formatado": "pre"
	},

	tooltips: {
		bold:           "Negrito",
		italic:         "Itlico",
		underline:      "Sublinhado",
		strikethrough:  "Tachado",
		subscript:      "Subscrito",
		superscript:    "Sobrescrito",
		justifyleft:    "Alinhar  esquerda",
		justifycenter:  "Centralizado",
		justifyright:   "Alinhar  direita",
		justifyfull:    "Justificado",
		insertorderedlist:    "Lista ordenada",
		insertunorderedlist:  "Lista com marcadores",
		outdent:        "Diminuir Indentao",
		indent:         "Aumentar Indentao",
		forecolor:      "Cor da Fonte",
		hilitecolor:    "Cor do Fundo",
		inserthorizontalrule: "Rgua Horizontal",
		createlink:     "Inserir link",
		insertimage:    "Inserir Imagem",
		insertsound:    "Inserir Som",
		inserttable:    "Inserir Tabela",
		htmlmode:       "Ver fonte HTML",
		popupeditor:    "Ampliar Editor",
		about:          "Sobre...",
		showhelp:       "Ajuda",
		textindicator:  "Estilo Atual",
		undo:           "Desfazer",
		redo:           "Refazer",
		cut:            "Recortar",
		copy:           "Copiar",
		paste:          "Colar"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Cancelar"
	},

	msg: {
		"Path":         "Caminho",
		"TEXT_MODE":    "Voce est no MODO TEXTO.  Use o boto [<>] para mudar para WYSIWIG."
	}
};
